# vue-lite-layer

### 说明

vue-lite-layer 是一款仿 layer 的 vue 插件。

### 功能项

1. 支持拖拽
2. 支持全屏及元素内弹窗

### 安装

```
yarn add vue-lite-layer
或
npm install vue-lite-layer
```

### 引用

```javascript
import Vue from 'vue'
import layer from 'vue-lite-layer'
import 'vue-lite-layer/dist/vue-lite-layer.css'

// options为全局参数
Vue.use(layer, options)
```

### 使用示例

```javascript
let instance = vm.$layer.open(options)
```

### 全局方法

|       方法名       |          说明           |
|:---------------:|:---------------------:|
|  open(option)   | 打开 layer 并返回 layer 实例 |
| close(instance) |     传入实例，关闭 layer     |     
|   closeAll()    |      关闭所有 layer       |

### 实例方法

|           方法名            |        说明         |
|:------------------------:|:-----------------:|
|  instance.close(value)   |   关闭当前实例，(可传值)    |
|     instance.reset()     |       重置大小        |
|      instance.max()      |      最大化当前实例      |
|  instance.autoCenter()   |       自动居中        |
| instance.resetLocation() | 还原位置（open 时设置的位置） |

### 实例内部调用

在自定义窗体内容中，可以调用 layer 的方法，

```javascript
// 关闭方法
vm.$layerUtils.close()
```

|    内部调用方法     |        说明         |
|:-------------:|:-----------------:|
| close(value)  |    关闭当前实例(可传值)    |
|    reset()    |       重置大小        |
|     max()     |      最大化当前实例      |
| autoCenter()  |       自动居中        |
| resetLocation | 还原位置（open 时设置的位置） |
| showLoading() |      显示加载动画       |
| hideLoading() |      隐藏加载动画       |

### option 参数选项

|      属性名      |                属性说明                 |              默认值              |
|:-------------:|:-----------------------------------:|:-----------------------------:|
|     title     |           标题,可传入字符串或者是组件            |              ''               |
|    footer     |              窗脚，可传入组件               |            内置窗脚组件             |
|     shade     |               是否有遮罩层                |             true              |
|  shadeClose   |              是否点击遮罩关闭               |             false             |
|   location    |          窗口首次打开位置，字符串或者是对象          |             'cc'              |
|     area      |               窗口大小，对象               | {height:'300px',width:'300px' |
| appendElement | 窗口放在哪个元素下面,传入 dom 元素，如果是 null 则全屏显示 |             null              |
|    content    |              窗体内容，传入组件              |             null              |
|   propsData   |         窗体内容传值，就是vue的props          ||
|    zIndex     |              窗体的ZIndex              |              100              |
|    hasMax     |               是否可以最大化               |             true              |
|   hasClose    |              是否有最关闭按钮               |             true              |
|  beforeOpen   |            回调函数，窗体打开关触发             ||
|  beforeClose  | 回调函数，窗体关闭前触发（如果close时候传值了，这里会把值传出来） ||

### location 参数选项
#### 字符串
| 参数  | 说明  |
|:---:|:---:|
| lt  | 左上  |
| lc  | 左中  |
| lb  | 左下  |
| ct  | 中上  |
| cc  | 中中  |
| cb  | 中下  |
| rt  | 左上  |
| rc  | 右中  |
| rb  | 右下  |
#### 对象
|  参数  |      说明       |
|:----:|:-------------:|
| left | 左边距离,例: 300px |
| top  | 上边距离，例：100px  |
### 简单用例
LayerTestForm.vue
```vue
<template>
  <div>
    <button @click="close">关闭</button>
    <button @click="loading">loading</button>
    <button @click="max">最大</button>
    <button @click="reset">还原</button>
    <button @click="center">居中</button>
    <button @click="relocation">重置位置</button>
    <div>{{ outerText }}</div>
  </div>
</template>

<script>
export default {
  name: 'LayerTestForm',
  props: {
    outerText: {
      type: String,
      default: '默认消息',
    },
  },
  methods: {
    loading() {
      const that = this
      this.$layerUtils.showLoading()
      setTimeout(() => {
        that.$layerUtils.hideLoading()
      }, 5000)
    },
    close() {
      this.$layerUtils.close()
    },
    max() {
      this.$layerUtils.max()
    },
    reset() {
      this.$layerUtils.reset()
    },
    center() {
      this.$layerUtils.autoCenter()
    },
    relocation() {
      this.$layerUtils.resetLocation()
    },
    onOk() {
      // 当点击“确认”时，传心入
      console.log('ok click')
      this.$layerUtils.close("ok")
    },
  },
}
</script>
```
页面中使用
```javascript
import LayerTestForm from '@/components/LayerTestForm'

export default {
  name: 'App',
  methods: {
    openLayer() {
      this.$layer.open({
        content: LayerTestForm,
        shadeClose: true,
        multiply: true,
        shade: true,
        area: {
          width: '500px',
        },
        propsData: {
          outerText: '外部消息',
        },
      })
    },
    closeAll() {
      this.$layer.closeAll()
    },
  },
}
```
